aboutsummaryrefslogtreecommitdiff
path: root/engines/sword1
diff options
context:
space:
mode:
Diffstat (limited to 'engines/sword1')
-rw-r--r--engines/sword1/animation.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/engines/sword1/animation.cpp b/engines/sword1/animation.cpp
index 498f185f70..afe9a13bd1 100644
--- a/engines/sword1/animation.cpp
+++ b/engines/sword1/animation.cpp
@@ -348,9 +348,9 @@ void MoviePlayerDXA::processFrame(void) {
}
void MoviePlayerDXA::updateScreen(void) {
// Using _scaledBuffer directly should work, as long as we don't do any
// post-processing of the frame.
- _sys->copyRectToScreen(_scaledBuffer, _frameWidth, _frameX, _frameY, _frameWidth, _frameHeight);
+ _sys->copyRectToScreen(_drawBuffer, _frameWidth, _frameX, _frameY, _frameWidth, _frameHeight);
_sys->updateScreen();
}
@@ -348,9 +348,9 @@ void MoviePlayerDXA::processFrame(void) {
}
void MoviePlayerDXA::updateScreen(void) {
- // Using _scaledBuffer directly should work, as long as we don't do any
+ // Using _drawBuffer directly should work, as long as we don't do any
// post-processing of the frame.